warp_perspective method

bool warp_perspective(
  1. Pointer<Uint8> frame,
  2. int width,
  3. int height,
  4. Quad quad,
  5. Pointer<Uint8> out_buffer,
  6. int out_width,
  7. int out_height,
)

Warps the region of frame bounded by quad into out_buffer, producing a straightened, cropped single-channel image of size out_width x out_height. Returns false if the homography could not be solved.

Implementation

bool warp_perspective(
  ffi.Pointer<ffi.Uint8> frame,
  int width,
  int height,
  Quad quad,
  ffi.Pointer<ffi.Uint8> out_buffer,
  int out_width,
  int out_height,
) {
  return _warp_perspective(
    frame,
    width,
    height,
    quad,
    out_buffer,
    out_width,
    out_height,
  );
}