warp_perspective method
Warps the region of frame bounded by quad into out_buffer, producing
a straightened, cropped single-channel image of size out_width x
out_height. Returns false if the homography could not be solved.
Implementation
bool warp_perspective(
ffi.Pointer<ffi.Uint8> frame,
int width,
int height,
Quad quad,
ffi.Pointer<ffi.Uint8> out_buffer,
int out_width,
int out_height,
) {
return _warp_perspective(
frame,
width,
height,
quad,
out_buffer,
out_width,
out_height,
);
}